# Module: tide.maxwell

TODO: Add signatures, parameter descriptions, and examples.

## Public API
- class MaxwellTM
- function maxwelltm

## Advanced or Internal Functions
- prepare_parameters
- maxwell_func
- maxwell_python
- update_E
- update_H
- maxwell_c_cuda

## Autograd Functions
- MaxwellTMForwardFunc
- MaxwellTMForwardBoundaryFunc

## Internal Helpers
- _register_ctx_handle
- _get_ctx_handle
- _release_ctx_handle
- _compute_boundary_indices_flat
